# hello-emoji 🤩

`hello-emoji` is a random smiley generator.


# installation

```
pip install hello-emoji
```
# usage

Here are few examples 👇

```
>>> import hello_emoji
>>> hello_emoji.hello_emoji()
'Hello 🤣!'
>>> hello_emoji.hello_emoji()
'Hello 😋!'
>>> hello_emoji.hello_emoji()
'Hello 😊!'
```
Here are few examples using `from` and `import` syntax. 

```
>>> from hello_emoji import hello_emoji
>>> hello_emoji()
'Hello 😄!'
>>> hello_emoji()
'Hello 😍!'
>>> hello_emoji()
'Hello 😊!'
>>> hello_emoji()
'Hello 😄!'
>>> hello_emoji()
'Hello 🤣!'
```